@@ -16,11 +16,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from functools import wraps
 from importlib import import_module
 import os
 import traceback
 import unittest
+from unittest import mock
 
 import django
 from django.conf import settings
@@ -31,19 +31,16 @@ from django.utils import http
 
 from heatclient import client as heat_client
 from keystoneclient.v2_0 import client as keystone_client
-import mock
 from neutronclient.v2_0 import client as neutron_client
 from openstack_auth import user
 from openstack_auth import utils
 from requests.packages.urllib3.connection import HTTPConnection
 
-import six
-from six import moves
-
 from horizon.test import helpers as horizon_helpers
 
 from openstack_dashboard import api as project_api
 from openstack_dashboard import context_processors
+from openstack_dashboard.test import helpers
 
 from heat_dashboard import api
 from heat_dashboard.test.test_data import utils as test_utils
@@ -51,60 +48,11 @@ from heat_dashboard.test.test_data import utils as test_utils
 # Makes output of failing mox tests much easier to read.
 wsgi.WSGIRequest.__repr__ = lambda self: "<class 'django.http.HttpRequest'>"
 
-
-def create_stubs(stubs_to_create=None):
-    """decorator to simplify setting up multiple stubs at once via mox
-
-    :param stubs_to_create: methods to stub in one or more modules
-    :type stubs_to_create: dict
-
-    The keys are python paths to the module containing the methods to mock.
-
-    To mock a method in openstack_dashboard/api/nova.py, the key is::
-
-        api.nova
-
-    The values are either a tuple or list of methods to mock in the module
-    indicated by the key.
-
-    For example::
-
-        ('server_list',)
-            -or-
-        ('flavor_list', 'server_list',)
-            -or-
-        ['flavor_list', 'server_list']
-
-    Additionally, multiple modules can be mocked at once::
-
-        {
-            api.nova: ('flavor_list', 'server_list'),
-            api.glance: ('image_list_detailed',),
-        }
-
-    """
-    if stubs_to_create is None:
-        stubs_to_create = {}
-    if not isinstance(stubs_to_create, dict):
-        raise TypeError("create_stub must be passed a dict, but a %s was "
-                        "given." % type(stubs_to_create).__name__)
-
-    def inner_stub_out(fn):
-        @wraps(fn)
-        def instance_stub_out(self, *args, **kwargs):
-            for key in stubs_to_create:
-                if not (isinstance(stubs_to_create[key], tuple) or
-                        isinstance(stubs_to_create[key], list)):
-                    raise TypeError("The values of the create_stub "
-                                    "dict must be lists or tuples, but "
-                                    "is a %s."
-                                    % type(stubs_to_create[key]).__name__)
-
-                for value in stubs_to_create[key]:
-                    self.mox.StubOutWithMock(key, value)
-            return fn(self, *args, **kwargs)
-        return instance_stub_out
-    return inner_stub_out
+# Shortcuts to avoid importing openstack_dashboard.test.helper and
+# for backwards compatibility.
+create_mocks = helpers.create_mocks
+IsA = helpers.IsA
+IsHttpRequest = helpers.IsHttpRequest
 
 
 def _apply_panel_mocks(patchers=None):
@@ -165,10 +113,6 @@ class TestCase(horizon_helpers.TestCase):
     # boolean variable to store failures
     missing_mocks = False
 
-    # heat-dashboard depends on mox and we need to declare it.
-    # horizon UT disables mox by default now.
-    use_mox = True
-
     def fake_conn_request(self):
         # print a stacktrace to illustrate where the unmocked API call
         # is being made from
@@ -235,18 +179,20 @@ class TestCase(horizon_helpers.TestCase):
                       authorized_tenants=None, enabled=True, domain_id=None,
                       user_domain_name=None):
         def get_user(request):
-            return user.User(id=id,
-                             token=token,
-                             user=username,
-                             domain_id=domain_id,
-                             user_domain_name=user_domain_name,
-                             tenant_id=tenant_id,
-                             tenant_name=tenant_name,
-                             service_catalog=service_catalog,
-                             roles=roles,
-                             enabled=enabled,
-                             authorized_tenants=authorized_tenants,
-                             endpoint=settings.OPENSTACK_KEYSTONE_URL)
+            ret = user.User(id=id,
+                            token=token,
+                            user=username,
+                            domain_id=domain_id,
+                            user_domain_name=user_domain_name,
+                            tenant_id=tenant_id,
+                            tenant_name=tenant_name,
+                            service_catalog=service_catalog,
+                            roles=roles,
+                            enabled=enabled,
+                            authorized_tenants=authorized_tenants,
+                            endpoint=settings.OPENSTACK_KEYSTONE_URL)
+            ret._is_system_user = False
+            return ret
         utils.get_user = get_user
 
     def assertRedirectsNoFollow(self, response, expected_url):
@@ -256,7 +202,10 @@ class TestCase(horizon_helpers.TestCase):
         processing the view which is redirected to.
         """
         if django.VERSION >= (1, 9):
-            loc = six.text_type(response._headers.get('location', None)[1])
+            if response.has_header('location'):
+                loc = response['location']
+            else:
+                loc = ''
             loc = http.urlunquote(loc)
             expected_url = http.urlunquote(expected_url)
             self.assertEqual(loc, expected_url)
@@ -294,7 +243,7 @@ class TestCase(horizon_helpers.TestCase):
             assert len(errors) == count, \
                 "%d errors were found on the form, %d expected" % \
                 (len(errors), count)
-            if message and message not in six.text_type(errors):
+            if message and message not in str(errors):
                 self.fail("Expected message not found, instead found: %s"
                           % ["%s: %s" % (key, [e for e in field_errors]) for
                              (key, field_errors) in errors.items()])
@@ -318,13 +267,13 @@ class TestCase(horizon_helpers.TestCase):
     def getAndAssertTableRowAction(self, response, table_name,
                                    action_name, row_id):
         table = response.context[table_name + '_table']
-        rows = list(moves.filter(lambda x: x.id == row_id,
-                                 table.data))
+        rows = list(filter(lambda x: x.id == row_id,
+                           table.data))
         self.assertEqual(1, len(rows),
                          "Did not find a row matching id '%s'" % row_id)
         row_actions = table.get_row_actions(rows[0])
-        actions = list(moves.filter(lambda x: x.name == action_name,
-                                    row_actions))
+        actions = list(filter(lambda x: x.name == action_name,
+                              row_actions))
 
         msg_args = (action_name, table_name, row_id)
         self.assertGreater(
@@ -342,8 +291,8 @@ class TestCase(horizon_helpers.TestCase):
 
         table = response.context[table_name + '_table']
         table_actions = table.get_table_actions()
-        actions = list(moves.filter(lambda x: x.name == action_name,
-                                    table_actions))
+        actions = list(filter(lambda x: x.name == action_name,
+                              table_actions))
         msg_args = (action_name, table_name)
         self.assertGreater(
             len(actions), 0,
@@ -372,6 +321,7 @@ class BaseAdminViewTests(TestCase):
 
     For testing admin-only views and functionality.
     """
+
     def setActiveUser(self, *args, **kwargs):
         if "roles" not in kwargs:
             kwargs['roles'] = [self.roles.admin._info]
@@ -395,6 +345,7 @@ class APITestCase(TestCase):
     For use with tests which deal with the underlying clients rather than
     stubbing out the openstack_dashboard.api.* methods.
     """
+
     def setUp(self):
         super(APITestCase, self).setUp()
         utils.patch_middleware_get_user()
@@ -423,7 +374,7 @@ class APITestCase(TestCase):
 
     def stub_keystoneclient(self):
         if not hasattr(self, "keystoneclient"):
-            self.mox.StubOutWithMock(keystone_client, 'Client')
+            keystone_client.Client = mock.Mock()
             # NOTE(saschpe): Mock properties, MockObject.__init__ ignores them:
             keystone_client.Client.auth_token = 'foo'
             keystone_client.Client.service_catalog = None
@@ -431,24 +382,25 @@ class APITestCase(TestCase):
             keystone_client.Client.tenant_name = 'tenant_1'
             keystone_client.Client.management_url = ""
             keystone_client.Client.__dir__ = lambda: []
-            self.keystoneclient = self.mox.CreateMock(keystone_client.Client)
+            self.keystoneclient = keystone_client.Client
         return self.keystoneclient
 
     def stub_neutronclient(self):
         if not hasattr(self, "neutronclient"):
-            self.mox.StubOutWithMock(neutron_client, 'Client')
-            self.neutronclient = self.mox.CreateMock(neutron_client.Client)
+            neutron_client.Client = mock.Mock()
+            self.neutronclient = neutron_client.Client
         return self.neutronclient
 
     def stub_heatclient(self):
         if not hasattr(self, "heatclient"):
-            self.mox.StubOutWithMock(heat_client, 'Client')
-            self.heatclient = self.mox.CreateMock(heat_client.Client)
+            heat_client.Client = mock.Mock()
+            self.heatclient = heat_client.Client
         return self.heatclient
 
 
 # Need this to test both Glance API V1 and V2 versions
 class ResetImageAPIVersionMixin(object):
+
     def setUp(self):
         super(ResetImageAPIVersionMixin, self).setUp()
         project_api.glance.VERSIONS.clear_active_cache()
